@@ -58,10 +58,11 @@ void nsUniversalDetector::Reset()
     }
 
     unsigned int i;
-    for (i = 0; i < NUM_OF_CHARSET_PROBERS; i++)
+    for (i = 0; i < NUM_OF_CHARSET_PROBERS; i++) {
         if (mCharSetProbers[i]) {
             mCharSetProbers[i]->Reset();
         }
+    }
 }
 
 //---------------------------------------------------------------------
@@ -80,7 +81,7 @@ nsProbingState nsUniversalDetector::HandleData(const char *aBuf, unsigned int aL
 
     unsigned int i;
     for (i = 0; i < aLen; i++) {
-        // other than 0xa0, if every othe character is ascii, the page is ascii
+        // other than 0xa0, if every other character is ascii, the page is ascii
         if (aBuf[i] & '\x80' && aBuf[i] != '\xA0') { // Since many Ascii only page contains NBSP
             // we got a non-ascii byte (high-byte)
             if (mInputState != eHighbyte) {
